==> huaweicloudsdkcloudpond-3.1.81-py2.py3-none-any.whl: huaweicloudsdkcloudpond/v1/model/show_rack_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowRackResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'rack': 'Rack'
    }

    attribute_map = {
        'rack': 'rack'
    }

    def __init__(self, rack=None):
        """ShowRackResponse

        The model defined in huaweicloud sdk

        :param rack: 
        :type rack: :class:`huaweicloudsdkcloudpond.v1.Rack`
        """
        
        super(ShowRackResponse, self).__init__()

        self._rack = None
        self.discriminator = None

        if rack is not None:
            self.rack = rack

    @property
    def rack(self):
        """Gets the rack of this ShowRackResponse.

        :return: The rack of this ShowRackResponse.
        :rtype: :class:`huaweicloudsdkcloudpond.v1.Rack`
        """
        return self._rack

    @rack.setter
    def rack(self, rack):
        """Sets the rack of this ShowRackResponse.

        :param rack: The rack of this ShowRackResponse.
        :type rack: :class:`huaweicloudsdkcloudpond.v1.Rack`
        """
        self._rack = rack

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowRackResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudpond-3.1.148-py2.py3-none-any.whl: huaweicloudsdkcloudpond/v1/model/show_rack_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowRackResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'rack': 'Rack'
    }

    attribute_map = {
        'rack': 'rack'
    }

    def __init__(self, rack=None):
        r"""ShowRackResponse

        The model defined in huaweicloud sdk

        :param rack: 
        :type rack: :class:`huaweicloudsdkcloudpond.v1.Rack`
        """
        
        super(ShowRackResponse, self).__init__()

        self._rack = None
        self.discriminator = None

        if rack is not None:
            self.rack = rack

    @property
    def rack(self):
        r"""Gets the rack of this ShowRackResponse.

        :return: The rack of this ShowRackResponse.
        :rtype: :class:`huaweicloudsdkcloudpond.v1.Rack`
        """
        return self._rack

    @rack.setter
    def rack(self, rack):
        r"""Sets the rack of this ShowRackResponse.

        :param rack: The rack of this ShowRackResponse.
        :type rack: :class:`huaweicloudsdkcloudpond.v1.Rack`
        """
        self._rack = rack

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowRackResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
